@@ -3,7 +3,7 @@
  * logtofile_filename.c
  *      Functions to calculate the filename of the log file
  *
- * Copyright (c) 2020-2025, Francisco Miguel Biete Banon
+ * Copyright (c) 2020-2026, Francisco Miguel Biete Banon
  *
  * This code is released under the PostgreSQL licence, as given at
  *  http://www.postgresql.org/about/licence/
@@ -79,14 +79,15 @@ pgauditlogtofile_tm2filename(const struct pg_tm *tm)
   char *filename = NULL;
   int len;
 
-  filename = palloc(MAXPGPATH * sizeof(char *));
-  if (filename != NULL)
-  {
-    memset(filename, 0, sizeof(char) * MAXPGPATH);
-    snprintf(filename, MAXPGPATH, "%s/", guc_pgaudit_ltf_log_directory);
-    len = strlen(filename);
-    pg_strftime(filename + len, MAXPGPATH - len, guc_pgaudit_ltf_log_filename, tm);
-  }
+  filename = palloc(MAXPGPATH);
+
+  /* Write directory prefix */
+  pg_snprintf(filename, MAXPGPATH, "%s/", guc_pgaudit_ltf_log_directory);
+
+  len = strlen(filename);
+
+  /* Append formatted timestamp-based filename */
+  pg_strftime(filename + len, MAXPGPATH - len, guc_pgaudit_ltf_log_filename, tm);
 
   return filename;
 }
