@@ -3,7 +3,7 @@
  * logtofile_guc.h
  *      GUC variables for logtofile
  *
- * Copyright (c) 2020-2025, Francisco Miguel Biete Banon
+ * Copyright (c) 2020-2026, Francisco Miguel Biete Banon
  *
  * This code is released under the PostgreSQL licence, as given at
  *  http://www.postgresql.org/about/licence/
@@ -15,7 +15,8 @@
 #include <postgres.h>
 #include <utils/guc.h>
 
-extern bool guc_check_directory(char **newval, void **extra, GucSource source);
-extern bool guc_check_log_format(char **newval, void **extra, GucSource source);
+extern bool PgAuditLogToFile_guc_check_directory(char **newval, void **extra, GucSource source);
+extern bool PgAuditLogToFile_guc_check_log_format(char **newval, void **extra, GucSource source);
+extern const char *PgAuditLogToFile_guc_show_file_mode(void);
 
 #endif
