@@ -3,7 +3,7 @@
  * logtofile_log.c
  *      Functions to write audit logs to file
  *
- * Copyright (c) 2020-2025, Francisco Miguel Biete Banon
+ * Copyright (c) 2020-2026, Francisco Miguel Biete Banon
  *
  * This code is released under the PostgreSQL licence, as given at
  *  http://www.postgresql.org/about/licence/
@@ -234,11 +234,11 @@ bool pgauditlogtofile_open_file(void)
   (void)MakePGDirectory(guc_pgaudit_ltf_log_directory);
 
   /*
-   * Note we do not let Log_file_mode disable IWUSR, since we certainly want
+   * Note we do not let guc_pgaudit_ltf_log_file_mode disable IWUSR, since we certainly want
    * to be able to write the files ourselves.
    */
   oumask = umask(
-      (mode_t)((~(Log_file_mode | S_IWUSR)) & (S_IRWXU | S_IRWXG | S_IRWXO)));
+      (mode_t)((~(guc_pgaudit_ltf_log_file_mode | S_IWUSR)) & (S_IRWXU | S_IRWXG | S_IRWXO)));
   pgaudit_ltf_file_handler = fopen(pgaudit_ltf_shm->filename, "a");
   umask(oumask);
 
@@ -272,6 +272,7 @@ bool pgauditlogtofile_open_file(void)
 bool pgauditlogtofile_write_audit(const ErrorData *edata, int exclude_nchars)
 {
   StringInfoData buf;
+  bool success = false;
   int rc = 0;
 
   initStringInfo(&buf);
@@ -287,19 +288,28 @@ bool pgauditlogtofile_write_audit(const ErrorData *edata, int exclude_nchars)
 
   if (pgaudit_ltf_file_handler)
   {
-    fseek(pgaudit_ltf_file_handler, 0L, SEEK_END);
-    rc = fwrite(buf.data, 1, buf.len, pgaudit_ltf_file_handler);
-    pfree(buf.data);
-    fflush(pgaudit_ltf_file_handler);
+    /* multi-process write, move to end*/
+    if (fseek(pgaudit_ltf_file_handler, 0L, SEEK_END) == 0)
+    {
+      rc = fwrite(buf.data, 1, buf.len, pgaudit_ltf_file_handler);
+      if (rc == buf.len && fflush(pgaudit_ltf_file_handler) == 0)
+        success = true;
+      else
+      {
+        ereport(LOG_SERVER_ONLY,
+                (errcode_for_file_access(),
+                 errmsg("could not write audit log file \"%s\": %m", filename_in_use)));
+        pgauditlogtofile_close_file();
+      }
+    }
+    else
+    {
+      ereport(LOG_SERVER_ONLY,
+              (errcode_for_file_access(),
+               errmsg("could not seek to end of audit log file \"%s\": %m", filename_in_use)));
+      pgauditlogtofile_close_file();
+    }
   }
 
-  if (rc != buf.len)
-  {
-    ereport(LOG_SERVER_ONLY,
-            (errcode_for_file_access(),
-             errmsg("could not write audit log file \"%s\": %m", filename_in_use)));
-    pgauditlogtofile_close_file();
-  }
-
-  return rc == buf.len;
+  return success;
 }
\ No newline at end of file
