@@ -3,7 +3,7 @@
  * logtofile_string_format.c
  *      Functions to format data as strings
  *
- * Copyright (c) 2020-2025, Francisco Miguel Biete Banon
+ * Copyright (c) 2020-2026, Francisco Miguel Biete Banon
  *
  * This code is released under the PostgreSQL licence, as given at
  *  http://www.postgresql.org/about/licence/
@@ -30,12 +30,9 @@
 #include <storage/proc.h>
 #include <tcop/tcopprot.h>
 #include <utils/ps_status.h>
+#include <utils/timestamp.h>
 
-#include <pthread.h>
-#include <time.h>
-#include <sys/stat.h>
-
-#define FORMATTED_TS_LEN 128
+#define FORMATTED_TS_LEN 64
 
 /**
  * @brief Formats the record time
@@ -45,26 +42,22 @@
 char *PgAuditLogToFile_format_now_timestamp_millis(void)
 {
   char *formatted_log_time;
-  struct timeval tv;
-  char msbuf[5];
+  struct pg_tm tm;
+  fsec_t fsec;
+  const char *tzn;
 
-  formatted_log_time = palloc(FORMATTED_TS_LEN * sizeof(char));
+  formatted_log_time = palloc(FORMATTED_TS_LEN);
 
-  gettimeofday(&tv, NULL);
-
-  /*
-   * Note: we expect that guc.c will ensure that log_timezone is set up (at
-   * least with a minimal GMT value) before Log_line_prefix can become
-   * nonempty or CSV mode can be selected.
-   */
-  pg_strftime(formatted_log_time, FORMATTED_TS_LEN,
-              /* leave room for milliseconds... */
-              "%Y-%m-%d %H:%M:%S     %Z",
-              pg_localtime((pg_time_t *)&(tv.tv_sec), log_timezone));
-
-  /* 'paste' milliseconds into place... */
-  sprintf(msbuf, ".%03d", (int)(tv.tv_usec / 1000));
-  memcpy(formatted_log_time + 19, msbuf, 4);
+  if (timestamp2tm(GetCurrentTimestamp(), NULL, &tm, &fsec, &tzn, log_timezone) == 0)
+  {
+    pg_snprintf(formatted_log_time, FORMATTED_TS_LEN, "%04d-%02d-%02d %02d:%02d:%02d.%03d %s",
+                tm.tm_year, tm.tm_mon, tm.tm_mday, tm.tm_hour, tm.tm_min, tm.tm_sec,
+                (int)(fsec / 1000) /* milliseconds */, tzn);
+  }
+  else
+  {
+    strlcpy(formatted_log_time, "[invalid timestamp]", FORMATTED_TS_LEN);
+  }
 
   return formatted_log_time;
 }
